@@ -53,13 +53,7 @@ class Search(object):
         # Proxy? (I hope so!)
         if self.proxies != None:
             self.proxy = random.choice(self.proxies)
-            
-            # Is there a port spec?
-            if ':' in self.proxy:
-                proxy = self.proxy.split(':')
-                rq.set_proxies({'http' : proxy[0], 'port' : proxy[1]})
-            else:
-                rq.set_proxies({'http' : self.proxy})
+            rq.set_proxies({'http' : self.proxy})
         
         # Set options
         rq.set_handle_robots(False)
@@ -127,12 +121,7 @@ class Search(object):
                 # Put the failed proxy into garbage
                 self.garbage.append(self.proxy)
                 
-                # Is there a port spec?
-                if ':' in self.proxy:
-                    proxy = self.proxy.split(':')
-                    browser.set_proxies({'http' : proxy[0], 'port' : proxy[1]})
-                else:
-                    browser.set_proxies({'http' : self.proxy})
+                browser.set_proxies({'http' : self.proxy})
                 
                 # Recursion... (too bad Python doesn't TCR)
                 response = self._try(browser, request)
